*******************
Dorado Documentation
*******************

Digitized Observatory Resources for Automated Data Operations
=============

.. image:: https://img.shields.io/badge/Made%40-YorkObservatory-red
    :target: https://observatory.info.yorku.ca
    :alt: Made at YorkObservatory
.. image:: http://img.shields.io/badge/powered%20by-AstroPy-orange.svg?style=flat
    :target: http://www.astropy.org
    :alt: Powered by Astropy Badge
.. image:: https://readthedocs.org/projects/dorado/badge/?version=latest
    :target: https://dorado.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status
.. image:: https://img.shields.io/github/last-commit/Mucephie/DORADO
    :target: https://github.com/Mucephie/DORADO
    :alt: Last Commit
.. image:: https://img.shields.io/github/issues/Mucephie/DORADO
    :target: https://github.com/Mucephie/DORADO/issues
    :alt: GitHub issues
.. image:: https://img.shields.io/github/v/release/Mucephie/DORADO?include_prereleases
    :target: https://github.com/Mucephie/DORADO
    :alt: GitHub release (latest by date including pre-releases)

.. image:: https://img.shields.io/pypi/status/dorado
    :target: https://pypi.org/project/dorado/
    :alt: PyPI - Status
.. image:: https://img.shields.io/pypi/v/dorado
    :target: https://pypi.org/project/dorado/#history
    :alt: PyPI
.. image:: https://img.shields.io/pypi/format/dorado  
    :target: https://pypi.org/project/dorado/#files
    :alt: PyPI - Format
.. image:: https://img.shields.io/pypi/l/dorado   
    :target: https://pypi.org/project/dorado/
    :alt: PyPI - License
.. image:: https://img.shields.io/pypi/dm/dorado   
    :target: https://pypi.org/project/dorado/#files
    :alt: PyPI - Downloads



This is the documentation hub  for dorado.

.. toctree::
    :maxdepth: 2

    dorado/index







.. note:: Due to the nature of this project, these pages may change rapidly without notice. Effort is made to ensure these pages are up to date and effective.
